
local _, TzTB = ...

TzTB.icons = {}

-------------------------------------
-- TzTanaanBonusIcons_GetTexCoords --
-------------------------------------
function TzTanaanBonusIcons_GetTexCoords( _index )
	local y		= floor( _index / 8 )
	local x		= _index - ( y * 8 )
	local u1	= ( x + 0 ) / 8
	local u2	= ( x + 1 ) / 8
	local v1	= ( y + 0 ) / 8
	local v2	= ( y + 1 ) / 8

	return u1, u2, v1, v2
end

--------------------------------
-- TzTanaanBonusIcons_OnEnter --
--------------------------------
function TzTanaanBonusIcons_OnEnter( _self )
	if _self.text then
		WorldMapPOIFrame.allowBlobTooltip = false
		WorldMapTooltip:SetOwner( _self, "ANCHOR_BOTTOMLEFT" )
		WorldMapTooltip:ClearLines()
		WorldMapTooltip:AddLine( _self.text )

		if TomTom then
			WorldMapTooltip:AddLine( "Ctrl-Click to set a TomTom waypoint", 1, 1, 1, true )
		end

		WorldMapTooltip:Show()
	end

----------------------------------------------------------------

	_self.magic.frame.texture:SetVertexColor( 1.0, 1.0, 1.0 )
end

--------------------------------
-- TzTanaanBonusIcons_OnLeave --
--------------------------------
function TzTanaanBonusIcons_OnLeave( _self )
	WorldMapPOIFrame.allowBlobTooltip = true
	WorldMapTooltip:Hide()

----------------------------------------------------------------

	_self.magic.frame.texture:SetVertexColor( _self.magic.red, _self.magic.green, _self.magic.blue )
end

----------------------------------
-- TzTanaanBonusIcons_OnMouseUp --
----------------------------------
function TzTanaanBonusIcons_OnMouseUp( _self )
	if TomTom and IsControlKeyDown() then
		local mapID, mapFloor = GetCurrentMapAreaID()
		local _, _, _, x, y = _self:GetPoint()

		x =  x / WorldMapDetailFrame:GetWidth()		-- 1002
		y = -y / WorldMapDetailFrame:GetHeight()	--  668

		TomTom:AddMFWaypoint( mapID, mapFloor, x, y, { title = _self.text, persistent = false, } )
	end
end

-----------------------------
-- TzTanaanBonusIcons_Hide --
-----------------------------
function TzTanaanBonusIcons_Hide()
	for iconIndex, icon in ipairs( TzTB.icons ) do
		icon.frame:Hide()
		icon.image:Hide()
	end
end

----------------------------
-- TzTanaanBonusIcons_Get --
----------------------------
function TzTanaanBonusIcons_Get( _textureName, _blipID, _size, _red, _green, _blue, _alpha )
	local icon = nil

	for iconIndex, icon2 in ipairs( TzTB.icons ) do
		if not icon2.image:IsShown() then
			icon = icon2
			break
		end
	end

	if icon == nil then
		icon = {}
		icon.frame = CreateFrame( "Frame", nil, WorldMapButton )

		icon.frame.texture = icon.frame:CreateTexture()
		icon.frame.texture:SetAllPoints()
		icon.frame.texture:SetTexture( "interface/minimap/objecticons" )
		icon.frame.texture:SetTexCoord( TzTanaanBonusIcons_GetTexCoords( 31 ) )

		icon.frame.magic = icon

----------------------------------------------------------------

		icon.image = CreateFrame( "Frame", nil, WorldMapButton )

		icon.image.texture = icon.image:CreateTexture()
		icon.image.texture:SetAllPoints()

		icon.image:SetScript( "OnEnter", TzTanaanBonusIcons_OnEnter )
		icon.image:SetScript( "OnLeave", TzTanaanBonusIcons_OnLeave )
		icon.image:SetScript( "OnMouseUp", TzTanaanBonusIcons_OnMouseUp )

		icon.image:EnableMouse( true )

		icon.image.magic = icon

		tinsert( TzTB.icons, icon )
	end

	icon.red	= _red
	icon.green	= _green
	icon.blue	= _blue

	icon.frame.texture:SetVertexColor( icon.red, icon.green, icon.blue )

	icon.image.texture:SetTexture( _textureName )
	icon.image.texture:SetTexCoord( 0, 1, 0, 1 )

	if _blipID then
		icon.image.texture:SetTexCoord( TzTanaanBonusIcons_GetTexCoords( _blipID ) )
	end

	icon.frame:SetSize( _size, _size )
	icon.frame:SetAlpha( _alpha )

	icon.image:SetSize( _size * 0.75, _size * 0.75 )
	icon.image:SetAlpha( _alpha )

	return icon
end
